@@ -6,9 +6,14 @@ namespace LaminasTest\Stdlib;
 
 use Laminas\Stdlib\ArrayObject;
 
+/**
+ * @template TKey of array-key
+ * @template TValue
+ * @template-extends ArrayObject<TKey, TValue>
+ */
 final class CustomArrayObject extends ArrayObject
 {
-    protected bool $isImmutable = true;
+    private bool $isImmutable = true;
 
     public function isImmutable(): bool
     {
