@@ -10,13 +10,13 @@ use Laminas\Stdlib\StringWrapper\Intl;
 use function array_shift;
 use function extension_loaded;
 
-class IntlTest extends CommonStringWrapperTest
+class IntlTest extends CommonStringWrapperTestCase
 {
     protected function setUp(): void
     {
         if (! extension_loaded('intl')) {
             try {
-                new Intl('utf-8');
+                new Intl();
                 $this->fail('Missing expected Laminas\Stdlib\Exception\ExtensionNotLoadedException');
             } catch (Exception\ExtensionNotLoadedException) {
                 $this->markTestSkipped('Missing ext/intl');
@@ -26,13 +26,10 @@ class IntlTest extends CommonStringWrapperTest
         parent::setUp();
     }
 
-    /**
-     * @param null|string $encoding
-     * @param null|string $convertEncoding
-     * @return Intl|false
-     */
-    protected function getWrapper($encoding = null, $convertEncoding = null)
-    {
+    protected function getWrapper(
+        string|null $encoding = null,
+        string|null $convertEncoding = null,
+    ): Intl|false {
         if ($encoding === null) {
             $supportedEncodings = Intl::getSupportedEncodings();
             $encoding           = array_shift($supportedEncodings);
