@@ -10,13 +10,13 @@ use Laminas\Stdlib\StringWrapper\MbString;
 use function array_shift;
 use function extension_loaded;
 
-class MbStringTest extends CommonStringWrapperTest
+class MbStringTest extends CommonStringWrapperTestCase
 {
     protected function setUp(): void
     {
         if (! extension_loaded('mbstring')) {
             try {
-                new MbString('utf-8');
+                new MbString();
                 $this->fail('Missing expected Laminas\Stdlib\Exception\ExtensionNotLoadedException');
             } catch (Exception\ExtensionNotLoadedException) {
                 $this->markTestSkipped('Missing ext/mbstring');
@@ -26,13 +26,10 @@ class MbStringTest extends CommonStringWrapperTest
         parent::setUp();
     }
 
-    /**
-     * @param null|string $encoding
-     * @param null|string $convertEncoding
-     * @return MbString|false
-     */
-    protected function getWrapper($encoding = null, $convertEncoding = null)
-    {
+    protected function getWrapper(
+        string|null $encoding = null,
+        string|null $convertEncoding = null,
+    ): MbString|false {
         if ($encoding === null) {
             $supportedEncodings = MbString::getSupportedEncodings();
             $encoding           = array_shift($supportedEncodings);
